@@ -1,7 +1,6 @@
-#' Generates, from one (or several) BIN file(s) of Multi-grain OSL measurements, a list of luminescence
-#' data and information before statistical analysis
+#' @title Generates, from one (or several) BIN file(s) of Multi-grain OSL measurements a list of luminescence data and information before statistical analysis
 #'
-#' This function is used to generate, from the BIN file(s), a list of values of:
+#' @description This function is used to generate, from the BIN file(s), a list of values of:
 #'
 #' \bold{Multi-grain} OSL intensities and associated uncertainties, regenerative doses, etc., which will be the input of the Bayesian models.
 #' To be easy-to-use, this function requires a rigorous organisation - all needed files should be arranged in one folder -
@@ -18,7 +17,7 @@
 #' If there is more than one BIN file per sample, see the details section for instructions regarding how to correctly fill the
 #' \code{FolderNames} vector.
 #'
-#' @param Nb_sample [integer] (**required**): number of
+#' @param Nb_sample [integer] (**required**): number of samples
 #'
 #' @param Nb_binfile [integer] (with default): number of BIN files. It must be equal to, or greater than \code{Nb_sample}.
 #'
@@ -26,15 +25,15 @@
 #' The length of this vector must be equal to \code{Nb_sample} and the sum of entries of this vector must be equal to \code{Nb_binfile}.
 #' If there is more than one BIN file per sample, see the details section for instructions regarding how to correctly fill \code{BinPerSample} vector.
 #' Otherwise, this vector must contain a list of 1 values.
-#' @param sepD [character] (with default): column separator in the DiscPose.csv files.
+#' @param sepD [character] (with default): column separator in the `DiscPose.csv` files.
 #'
-#' @param sepDE [character] (with default): column separator in the DoseEnv.csv files.
+#' @param sepDE [character] (with default): column separator in the `DoseEnv.csv` files.
 #'
-#' @param sepDS [character] (with default): column separator in the DoseLab.csv files.
+#' @param sepDS [character] (with default): column separator in the `DoseLab.csv` files.
 #'
-#' @param sepR [character] (with default): column separator in the Rule.csv files.
+#' @param sepR [character] (with default): column separator in the `Rule.csv` files.
 #'
-#' @param force_run1_at_a_time (*with default*): if set to `TRUE`, the order of the records is
+#' @param force_run1_at_a_time [logical] (*with default*): if set to `TRUE`, the order of the records is
 #' pushed to follow the one "Run 1 at a time" order (this is, all sequence steps were performed on
 #' one aliquot before moving to the next aliquot), regardless of their original sequence.
 #' The default is `FALSE` because `'BayLum'` assumes that the sample was measured with the
@@ -49,10 +48,11 @@
 #' @param ... further arguments that can be passed to [Luminescence::read_BIN2R].
 #'
 #' @details
-#' With \code{Path} and \code{FolderNames}, this function goes to the subfolders containing the BIN files and associated information to compute
+
+#' With \code{Path} and \code{FolderNames}, this function goes to the sub folders containing the BIN files and associated information to compute
 #' the luminescence data.\cr
 #'
-#' \bold{** What are the required files in each subfolder? **}\cr
+#' ** What are the required files in each subfolder? **\cr
 #'
 #' Each subfolder can be named, for example, as the sample name followed by a number; it must contain:
 #' \itemize{
@@ -66,21 +66,21 @@
 #'   and its variance (squared error), both in Gy;
 #'   \item \bold{rule.csv}, a csv file containing information on
 #'   \itemize{
-#'     \item beginSignal=  the first channel for summing the natural or regenerative OSL signal (typically 1 or 6);
-#'     \item endSignal= the last channel for summing the natural or regenerative OSL signal (typically 5 or 10);
-#'     \item beginBackground= the first channel for background estimation of the natural or regenerative OSL signal (typically 76 or 81);
-#'     \item endBackground= the last channel for background estimation of the natural or regenerative OSL signal (typically 95 or 100);
-#'     \item beginTest,
-#'     \item endTest,
-#'     \item beginTestBackground,
-#'     \item endTestBackground= same values as above, for the test dose response (typically the same values should be used);
-#'     \item inflatePercent= uncertainty arising from the instrument reproducibility (typically 0.02, i.e. 2\%);
-#'     \item nbOfLastCycleToRemove= number of cycles at the end of the SAR protocol which should not be included in the dose response curve fitting
+#'     \item `beginSignal=`  the first channel for summing the natural or regenerative OSL signal (typically 1 or 6);
+#'     \item `endSignal=` the last channel for summing the natural or regenerative OSL signal (typically 5 or 10);
+#'     \item `beginBackground=` the first channel for background estimation of the natural or regenerative OSL signal (typically 76 or 81);
+#'     \item `endBackground=` the last channel for background estimation of the natural or regenerative OSL signal (typically 95 or 100);
+#'     \item `beginTest`,
+#'     \item `endTest`,
+#'     \item `beginTestBackground`,
+#'     \item `endTestBackground=` same values as above, for the test dose response (typically the same values should be used);
+#'     \item `inflatePercent=` uncertainty arising from the instrument reproducibility (typically 0.02, i.e. 2\%);
+#'     \item `nbOfLastCycleToRemove=` number of cycles at the end of the SAR protocol which should not be included in the dose response curve fitting
 #'     (typically 1 if only a recycling test is performed, or 2 if both recycling and IR depletion are tested).\cr
 #'   }
 #' }
 #'
-#' \bold{** How to fill the} \code{FolderNames} \bold{vector? **}\cr
+#' ** How to fill the `FolderNames` vector? **\cr
 #'
 #' \code{FolderNames} is a vector of length \code{Nb_binfile}. \code{FolderNames[i]} is the name (e.g., Sample1-File1, or successive names separated by "/" signs,
 #' if BIN files are in subfolders, e.g. Sample1/File1) of the subfolder containing all informations on the BIN file of ID number \code{i}.
@@ -97,9 +97,9 @@
 #'   If conversely, \code{FolderNames=c(noun2,noun1)}, the analysis performed by \code{\link{AgeS_Computation}} would not be consistent.\cr
 #' }
 #'
-#' \bold{** How to fill the} \code{BinPerSample} \bold{vector? **}\cr
+#' ** How to fill the `BinPerSample` vector? **\cr
 #'
-#' \code{BinPerSample[i]} correponds to the number of BIN files for the sample whose number ID is equal to \code{i}.\cr
+#' \code{BinPerSample[i]} corresponds to the number of BIN files for the sample whose number ID is equal to \code{i}.\cr
 #' For example, let us consider a case with two samples (Sample1 and Sample2), with 2 BIN files for Sample1 and 1 for Sample2.
 #' In this case, \code{Nb_binfile}=3 and \code{Nb_sample}=2.
 #' The user may then set \code{FolderNames=c("Sample1-File1", "Sample1-File2", "Sample2-File1")}, in which case \code{"Sample1-1"} is the name of the subfolder containing the first BIN file
@@ -107,9 +107,9 @@
 #' for the second sample. In this case, \code{BinPerSample=c(2,1)}.
 #'
 #'
-#' For the general BIN-file structure, the reader is referred to the following website:  \code{http://www.nutech.dtu.dk/}
+#' For the general BIN-file structure, the reader is referred to the following website:  `http://www.nutech.dtu.dk/`
 #'
-#' The function \code{\link{read_BIN2R}} developed in \code{\link{Luminescence}} package is used to read the BIN files.
+#' The function [Luminescence::read_BIN2R] is used to read the BIN files.
 #'
 #'
 #' @return A list containing the following objects:
@@ -125,7 +125,7 @@
 #'   \item \bold{Nb_measurement}, a vector giving, for each BIN file, the number of measurements;
 #' }
 #'
-#' \bold{** How to save this list **}
+#' ** How to save this list **
 #'
 #' You can save this list in a .RData object. To do this, you can use the function \code{\link{save}}.
 #' Then, to load this list you can use the function \code{\link{load}} (see example section fore more details).
@@ -174,17 +174,21 @@ Generate_DataFile_MG <- function(
   #--- create object needed
   #---------------------------------------
   # BaSAR observations for samples
-  LT=list()     # corresponding to observation of natural and regenerated luminescence signal : N_{k,j}^(i) per sample
-  sLT=list()    # corresponding to error of observation of L : sigma_{N_{K,j}^(i)} per sample
-  ITimes=list() # corresponding to observation : t_{k,j}^(i) per sample
+  LT <- list()     # corresponding to observation of natural and regenerated luminescence signal : N_{k,j}^(i) per sample
+  sLT <- list()    # corresponding to error of observation of L : sigma_{N_{K,j}^(i)} per sample
+  ITimes <- list() # corresponding to observation : t_{k,j}^(i) per sample
+
+  ## check if the number of BIN-files makes sense
+  if(list.files(Path) |> tolower() |> grepl(pattern = "\\.bin") |> sum() != Nb_binfile[1])
+    warning("[Generate_DataFile_MG()] The total number of BIN-files does not match the number specified in Nb_binfile. Please double-check and correct the number otherwise this can lead to all kind of problems!", call. = FALSE)
 
   # information on bin file
-  dLab=matrix(1,ncol=Nb_binfile,nrow=2)  # corresponding to dose source rate of the lab : d_{lab} per sample
-  regDose=list()          # computed regenerated dose multiplying the 2 above lines per sample
-  J=rep(0,Nb_binfile)     # aliquot number per sample
-  Nb_measurement=rep(0,Nb_binfile) # measurement number per aliquot
-  K=rep(0,Nb_binfile)     # point number considered for the growth curve
-  ddot=matrix(1,ncol=Nb_binfile,nrow=2)   # the dose rate received by the sample during the time,
+  dLab <- matrix(1,ncol=Nb_binfile,nrow=2)  # corresponding to dose source rate of the lab : d_{lab} per sample
+  regDose <- list()          # computed regenerated dose multiplying the 2 above lines per sample
+  J <- rep(0,Nb_binfile)     # aliquot number per sample
+  Nb_measurement <- rep(0,Nb_binfile) # measurement number per aliquot
+  K <- rep(0,Nb_binfile)     # point number considered for the growth curve
+  ddot <- matrix(1,ncol=Nb_binfile,nrow=2)   # the dose rate received by the sample during the time,
   #   if there is various bin file for one sample, they must have the same ddot
 
   # Fetch additional arguments for read_BIN2R()----------------------------------------------------
@@ -396,10 +400,9 @@ Generate_DataFile_MG <- function(
     }
   }
 
-
   #--- return information needed to compute BaSAR analysis
   #---------------------------------------
-  Liste = list(
+  Liste <- list(
     "LT" = LT,
     "sLT" = sLT,
     "ITimes" = ITimes,
@@ -413,4 +416,3 @@ Generate_DataFile_MG <- function(
   return(Liste)
 }
 
-
