@@ -3,7 +3,7 @@ test_that("Full function test", {
   local_edition(3)
 
   ## prepare folder
-  path <- system.file("extdata/FER1", "", package="BayLum")
+  path <- system.file("extdata/FER1", "", package = "BayLum")
   folder <- ""
   nbsample <- 1
 
@@ -11,6 +11,7 @@ test_that("Full function test", {
   DATA <- expect_silent(Generate_DataFile_MG(
     Path = path,
     FolderNames = folder,
+    Nb_binfile = 1,
     Nb_sample = nbsample,
     verbose = FALSE))
 
@@ -31,5 +32,14 @@ test_that("Full function test", {
     Nb_sample = nbsample,
     force_run1_at_a_time = TRUE,
     verbose = FALSE))
+
+  ## trigger BIN-file warning
+  expect_warning(Generate_DataFile_MG(
+    Path = path,
+    Nb_binfile = 2,
+    FolderNames = folder,
+    Nb_sample = nbsample,
+    force_run1_at_a_time = TRUE,
+    verbose = FALSE), regexp = "\\[Generate\\_DataFile\\_MG\\(\\)\\] The total number.*")
 })
 
